@@ -20,7 +20,8 @@ import Data.Array.ST(STArray)
 
 import Prelude hiding ((!!))
 import Control.Monad(when,unless,forM,forM_,liftM2,foldM)
-import Data.Array.MArray(MArray(..),unsafeFreeze)
+import Data.Array.MArray(MArray(..))
+import Data.Array.Unsafe(unsafeFreeze)
 import Data.Array.IArray(Array,bounds,assocs,Ix(range))
 import qualified Data.IntMap.CharMap2 as CMap(findWithDefault)
 import Data.IntMap(IntMap)
